@@ -1,6 +1,6 @@
 import pandas as pd
 
-from airflow_commons.glossary import COMMA
+from airflow_commons.resources.glossary import COMMA, WHITE_SPACE
 from airflow_commons.logger import LOGGER
 from airflow_commons.resources.bigquery import (
     DEDUPLICATION_GET_AVAILABLE_PARTITIONS_FIELD_SQL_FILE,
@@ -448,7 +448,7 @@ def archive(
     if mode not in ARCHIVE_MODES:
         raise ValueError(
             "Invalid archive mode:{}. Acceptable column names are ".format(mode)
-            + COMMA.join(i for i in ARCHIVE_MODES)
+            + (COMMA + WHITE_SPACE).join(i for i in ARCHIVE_MODES)
         )
     client = connect(service_account_file=service_account_file)
 
