@@ -1,13 +1,14 @@
 from airflow_commons.logger import LOGGER
 
-from airflow_commons.utils.file_utils import read_sql
+from airflow_commons.internal.file_utils import read_sql
 
-from airflow_commons.utils.mysql.mysql_utils import upsert, get_db_engine
-from airflow_commons.utils.mysql.mysql_utils import update as update_util
-from airflow_commons.utils.mysql.sql_utils import get_delete_sql
-from airflow_commons.utils.mysql.sql_utils import get_select_all_sql
-from airflow_commons.utils.mysql.sql_utils import get_select_sql
-from airflow_commons.utils.mysql.sql_utils import get_row_count_sql
+from airflow_commons.internal.mysql.auth import get_db_engine
+from airflow_commons.internal.mysql.core import upsert
+from airflow_commons.internal.mysql.core import update as update_util
+from airflow_commons.internal.mysql.query_utils import get_delete_sql
+from airflow_commons.internal.mysql.query_utils import get_select_all_sql
+from airflow_commons.internal.mysql.query_utils import get_select_sql
+from airflow_commons.internal.mysql.query_utils import get_row_count_sql
 import pandas as pd
 
 
